import os
import datetime
import glob

# delete - delete all files that match pattern and was created before timepoint.
def delete(pattern, timepoint=datetime.datetime.today()):
    for path in glob.glob(pattern):
        if datetime.datetime.fromtimestamp(os.path.getatime(path)) < timepoint:
            os.remove(path)


# delete('/tmp/*',(datetime.datetime.now()-datetime.timedelta(minutes=10)))



from setuptools import setup

setup(name='file_deleter',
      version='0.0.2',
      description='Delete all files that match pattern and was created before timepoint.',
      url='https://github.com/estranium/file_deleter',
      author='Dmitry Shevelev',
      author_email='estranium@gmail.com',
      license='MIT',
      packages=['file_deleter'],
      zip_safe=False)
